==> am_mod_lbr_0_3.zip: am_mod_lbr_0_3/components/lbr/language/1/barnraiser_01/inc/lbr_common.inc.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

// MENU
$lang['menu_list'] = 							"list";
$lang['menu_create'] = 							"create";
$lang['menu_overview'] = 						"overview";
$lang['menu_label_do'] = 						"do";
$lang['menu_label_view'] = 						"view";
$lang['menu_label_library'] = 					"in this wiki set";
$lang['menu_home_page'] = 						"home page";
$lang['menu_participation'] = 					"participation";
$lang['menu_manage'] = 							"manage";
$lang['menu_invite'] = 							"invite";
$lang['menu_search'] = 							"search";
$lang['menu_meta'] =							"cloud";
$lang['menu_files'] =							"files";


// LIBRARY PARTICIPATION STATUS
$lang['user_status'][1] = 						"barred";
$lang['user_status'][2] = 						"pending";
$lang['user_status'][3] = 						"active";
$lang['user_status'][4] = 						"hold";
$lang['user_status'][5] = 						"invited";


// ARRAY LIBRARY TYPE
$lang['set_type'][1] = 						"auto registration";
$lang['set_type'][2] = 						"registration approval";
$lang['set_type'][3] = 						"invitation only";
$lang['set_type'][4] = 						"specific membership types only";



// LIBRARY PERMISSIONS
// set
$lang['resource']['lbr']['set'][1] = 			"allow export";
$lang['resource']['lbr']['set'][2] = 			"manage participation";
// page
$lang['resource']['lbr']['page'][1] = 			"lock (editor only editing)";
// contributor
$lang['resource']['lbr']['user'][1] = 			"allow revisioning";
$lang['resource']['lbr']['user'][2] = 			"manage participants";
$lang['resource']['lbr']['user'][4] = 			"manage pages";
$lang['resource']['lbr']['user'][8] = 			"allow invite";



// LIBRARY STATISTICS
$lang['statistic']['library'][1] = 				"total page revisions contributed";


// ARRAY PUBLISHING LEVELS
$lang['set_level'][4] = 						"registered people only";
$lang['set_level'][16] = 						"public (everyone)";


// SET STATUS
$lang['set_status'][1] = 						"live";
$lang['set_status'][2] = 						"archive";


// ROLES
$lang['user_role'][1] = 						"sub-editor";

?>

==> am_mod_lbr_0_5.zip: am_mod_lbr_0_5/components/lbr/language/1/barnraiser_01/inc/lbr_common.inc.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

// MENU
$lang['menu_list'] = 							"list";
$lang['menu_create'] = 							"create";
$lang['menu_overview'] = 						"overview";
$lang['menu_label_do'] = 						"do";
$lang['menu_label_view'] = 						"view";
$lang['menu_label_library'] = 					"in this wiki set";
$lang['menu_home_page'] = 						"home page";
$lang['menu_participation'] = 					"participation";
$lang['menu_manage'] = 							"manage";
$lang['menu_invite'] = 							"invite";
$lang['menu_search'] = 							"search";
$lang['menu_meta'] =							"cloud";
$lang['menu_files'] =							"files";


// ARRAY LIBRARY TYPE
$lang['set_type'][1] = 							"auto registration";
$lang['set_type'][2] = 							"registration approval";
$lang['set_type'][3] = 							"invitation only";
$lang['set_type'][4] = 							"specific membership types only";

// LIBRARY PERMISSIONS
// set
$lang['resource']['lbr']['set'][1] = 			"allow export";
$lang['resource']['lbr']['set'][2] = 			"manage participation";
// page
$lang['resource']['lbr']['page'][1] = 			"lock (editor only editing)";
// contributor
$lang['resource']['lbr']['user'][1] = 			"allow revisioning";
$lang['resource']['lbr']['user'][2] = 			"manage participants";
$lang['resource']['lbr']['user'][4] = 			"manage pages";
$lang['resource']['lbr']['user'][8] = 			"allow invite";



// LIBRARY STATISTICS
$lang['statistic']['library'][1] = 				"total page revisions contributed";
$lang['statistic']['library'][2] = 				"total comments for all wiki-sets";
$lang['statistic']['library'][3] = 				"total comments for this wiki-set";


// ARRAY PUBLISHING LEVELS
$lang['set_level'][4] = 						"registered people only";
$lang['set_level'][16] = 						"public (everyone)";


// SET STATUS
$lang['set_status'][1] = 						"live";
$lang['set_status'][2] = 						"archive";


// ROLES
$lang['user_role'][1] = 						"sub-editor";

?>
